#[non_exhaustive]#[repr(u8)]pub enum ElevatedRunLevel {
Level1 = 1,
Level2 = 2,
Level3 = 3,
Level4 = 4,
Level5 = 5,
Level6 = 6,
Level7 = 7,
}Expand description
Interrupt run levels.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Level1 = 1
Run level 1.
Level2 = 2
Run level 2.
Level3 = 3
Run level 3.
Level4 = 4
Run level 4.
Level5 = 5
Run level 5.
Level6 = 6
Run level 6.
Level7 = 7
Run level 7.
Implementations
Sourceimpl ElevatedRunLevel
impl ElevatedRunLevel
Sourcepub const fn max() -> ElevatedRunLevel
Available on crate feature unstable only.
pub const fn max() -> ElevatedRunLevel
unstable only.Maximum interrupt run level
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub const fn min() -> ElevatedRunLevel
pub const fn min() -> ElevatedRunLevel
Minimum interrupt run level
Sourcepub const fn from_priority(priority: Priority) -> Self
pub const fn from_priority(priority: Priority) -> Self
Converts a Priority into an ElevatedRunLevel.